==> yaml_collection_06_11_2025-16_51.zip: app/snippets/display_collection.php <==
<?php
$im=new thumbnail_tool(CHEMIN,CACHE_VIGNETTES,APP."images/");

// si la collection n'a pas d'illu, prendre de la première image de la collection
$illu=$co->getFile("illustration");
if(!$illu){
    $liste=$co->getAsarray('items');

    $item=new yamlReadwriter();
    $snippet_item=getSnippetFile("display_item_mosaique.php");
    $item->loadYaml(getTemplate("structure_item.yaml")); // charger la structure complète

    
    for($i=0;$i<count($liste);$i++){
        $item->loadContentFromYaml(CONTENTS."items/".$liste[$i]);
        $illu=$item->getFile('illustration');
        if($illu){
            break;
        }
    }
}
$im->set_source(IMPORTS_URL.$illu);
?>
<article class="collection p-1 position-relative" >
    <div data-source="<?= $co->filename ?>" onclick="yc_showCollection(this,'<?= $co->filename ?>')">
        <div class="collection-header pb-2"> 
            <img src="<?= $im->vignette(400,200,true) ?>" class="collection-illu img-object-fit aspectratio-21">
        </div>
        <div class="item-infos">
            <h2 data-contenu='titre' class="fs-small"><?= $co->get('titre') ?></h2>
            <div class="collection-texte">
                <?= $co->get('texte') ?>
                <?php 
    if(STATUS=="admin"){
        echo "<div class='fs-small mt-3'><a href='".URL."?c=".basename($co->filename,".yaml")."' target='_blank'>Lien</a></div>";
    }
            ?>
            </div>
        </div>
        
        <?php
    if(isadmin()){
        ?>
        <div class="v-icon edit collection-edit" onclick="yc_editCollection(event,'<?= $co->filename ?>')"><img src="app/images/pencil-fill.svg"></div>
        <?php } ?>
    </div>
</article>

==> yaml_collection_18_12_2025-22_54.zip: app/snippets/display_collection.php <==
<?php
$im=new thumbnail_tool(CHEMIN,CACHE_VIGNETTES,APP."images/");

// si la collection n'a pas d'illu, prendre de la première image de la collection
$illu=$co->getFile("illustration");
if(!$illu){
    $liste=$co->getAsarray('items');

    $item=new yamlReadwriter();
    $snippet_item=getSnippetFile("display_item_mosaique.php");
    $item->loadYaml(getTemplate("structure_item.yaml")); // charger la structure complète

    
    for($i=0;$i<count($liste);$i++){
        $item->loadContentFromYaml(CONTENTS."items/".$liste[$i]);
        $illu=$item->getFile('illustration');
        if($illu){
            break;
        }
    }
}
$im->set_source(IMPORTS_URL.$illu);
?>
<article class="collection p-1 position-relative" >
    <div data-source="<?= $co->filename ?>" onclick="yc_showCollection(this,'<?= $co->filename ?>')">
        <div class="collection-header pb-2"> 
            <img src="<?= $im->vignette(400,200,true) ?>" class="collection-illu img-object-fit aspectratio-21">
        </div>
        <div class="item-infos">
            <h2 data-contenu='titre' class="fs-small"><?= $co->get('titre') ?></h2>
            <div class="collection-texte">
                <?= $co->get('texte') ?>
                <?php 
    if(STATUS=="admin"){
        
        // contourner la malformation de URL provenant de async
        $link_url=URL;
        if(strpos(URL, "app") !==false){
            $li=explode("app",URL);
            $link_url=$li[0];
        }
        echo "<div class='fs-small mt-3'><a href='".$link_url."?c=".basename($co->filename,".yaml")."' target='_blank'>Lien</a></div>";
    }
            ?>
            </div>
        </div>
        <?php
    if(isadmin()){
        ?>
        <div class="v-icon edit collection-edit" onclick="yc_editCollection(event,'<?= $co->filename ?>')"><img src="app/images/pencil-fill.svg"></div>
        <?php } ?>
    </div>
</article>
